Django-Scalable
===============

The Django-Scalable package introduces a base abstract Scalable class,
inherited from the Model class, and some number of utilities, appropriate
to spread processing a huge set of instances to any number of workers
running in parallel.

See details at the home page: https://github.com/nnseva/django-scalable
